@@ -21,6 +21,8 @@
 *
 */
 
+#include <QScreen>
+#include <QGuiApplication>
 #include "globals.h"
 
 QString globals::Globals::m_sig;
@@ -45,3 +47,15 @@ QString globals::Globals::magickVersion()
 
     return imVersion;
 }
+
+qreal globals::Globals::scaleFactor()
+{
+    qreal scale = 1.0;
+
+    if (QGuiApplication::screens().count() > 0) {
+        QScreen *screen = QGuiApplication::screens().at(0);
+        scale = screen->devicePixelRatio();
+    }
+
+    return scale;
+}
